@@ -4,6 +4,7 @@ for all commands.
 """
 
 import os
+from sys import exit
 from typing import List
 
 from pypac import pac_context_for_url
@@ -11,7 +12,8 @@ from yellowdog_client import PlatformClient
 from yellowdog_client.model import ApiKey, KeyringSummary, ServicesSchema
 
 from yd_commands.args import ARGS_PARSER
-from yd_commands.config import ConfigCommon, load_config_common
+from yd_commands.config_types import ConfigCommon
+from yd_commands.load_config import load_config_common
 from yd_commands.printing import print_error, print_log
 
 CONFIG_COMMON: ConfigCommon = load_config_common()
@@ -25,17 +27,11 @@ def dry_run() -> bool:
     """
     Is this a dry-run?
     """
-    try:
-        if ARGS_PARSER.dry_run is not None and ARGS_PARSER.dry_run:
-            return True
-    except AttributeError:
-        pass
-    try:
-        if ARGS_PARSER.process_csv_only is not None and ARGS_PARSER.process_csv_only:
-            return True
-    except AttributeError:
-        pass
-    return False
+    dry_run = ARGS_PARSER.dry_run or ARGS_PARSER.process_csv_only
+    if dry_run is None:
+        return False
+    else:
+        return dry_run
 
 
 def print_account():
@@ -44,12 +40,15 @@ def print_account():
     being at least one Keyring in the account. Omit if this is a dry run.
     """
     if not dry_run():
-        keyrings: List[KeyringSummary] = CLIENT.keyring_client.find_all_keyrings()
-        if len(keyrings) > 0:
-            # This is a little brittle, obviously
-            print_log(
-                f"YellowDog Account short identifier is: '{keyrings[0].id[13:19]}'"
-            )
+        try:
+            keyrings: List[KeyringSummary] = CLIENT.keyring_client.find_all_keyrings()
+            if len(keyrings) > 0:
+                # This is a little brittle, obviously
+                print_log(
+                    f"YellowDog Account short identifier is: '{keyrings[0].id[13:19]}'"
+                )
+        except:
+            pass
 
 
 def set_proxy():
@@ -84,6 +83,7 @@ def main_wrapper(func):
                 print_error(e)
                 exit_code = 1
             except KeyboardInterrupt:
+                print("\r", end="")  # Overwrite the display of ^C
                 print_log("Cancelled")
                 exit_code = 1
             finally:
